{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Assign Clade, align_sort",
            "hints": [
                {
                    "dockerPull": "ncbi/gpdev:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "align_sort",
            "arguments": [
                "-ifmt",
                "seq-align-set",
                "-k",
                "query,subject",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_sort.cwl/hits"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "sorted-aligns.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_sort.cwl/output"
                }
            ],
            "id": "#align_sort.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_sort.cwl/sorted_aligns"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Assign Clade, assign_clade_bacteria",
            "hints": [
                {
                    "dockerPull": "ncbi/gpdev:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "assign_clade_bacteria",
            "arguments": [
                "-comp_based_stats",
                "F",
                "-lower-threshold",
                "0.004",
                "-matrix",
                "BLOSUM80",
                "-min-markers",
                "17",
                "-release-id",
                "0",
                "-seg",
                "22 2.2 2.5",
                "-soft_masking",
                "true",
                "-task",
                "tblastn",
                "-threshold",
                "18",
                "-upper-threshold",
                "0.01",
                "-word_size",
                "6",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#assign_clade_bacteria.cwl/CladeMarkers_asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ani"
                    },
                    "id": "#assign_clade_bacteria.cwl/ani"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.CladeMarkers_asn_cache.basename)"
                    },
                    "id": "#assign_clade_bacteria.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-assembly-taxid"
                    },
                    "id": "#assign_clade_bacteria.cwl/assembly_id"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/panfs/pan1.be-md.ncbi.nlm.nih.gov/gpipe/etc/bact/ncbi.ini"
                    },
                    "inputBinding": {
                        "prefix": "-conffile"
                    },
                    "id": "#assign_clade_bacteria.cwl/conffile"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "clade_assignment.xml",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#assign_clade_bacteria.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-reference-set"
                    },
                    "id": "#assign_clade_bacteria.cwl/reference_set"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-hits"
                    },
                    "id": "#assign_clade_bacteria.cwl/sorted_aligns"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#assign_clade_bacteria.cwl/clade_assignment"
                }
            ],
            "id": "#assign_clade_bacteria.cwl"
        },
        {
            "class": "Workflow",
            "label": "Assign Clade",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/CladeMarkers_asn_cache"
                },
                {
                    "type": "File",
                    "id": "#main/ani"
                },
                {
                    "type": "Directory",
                    "id": "#main/asn_cache"
                },
                {
                    "type": "string",
                    "id": "#main/assembly_id"
                },
                {
                    "type": "File",
                    "id": "#main/hits"
                },
                {
                    "type": "File",
                    "id": "#main/reference_set"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/assign_clade_bacteria/clade_assignment",
                    "id": "#main/clade_assignment"
                }
            ],
            "steps": [
                {
                    "run": "#align_sort.cwl",
                    "in": [
                        {
                            "source": "#main/hits",
                            "id": "#main/align_sort/hits"
                        }
                    ],
                    "out": [
                        "#main/align_sort/sorted_aligns"
                    ],
                    "id": "#main/align_sort"
                },
                {
                    "run": "#assign_clade_bacteria.cwl",
                    "in": [
                        {
                            "source": "#main/CladeMarkers_asn_cache",
                            "id": "#main/assign_clade_bacteria/CladeMarkers_asn_cache"
                        },
                        {
                            "source": "#main/ani",
                            "id": "#main/assign_clade_bacteria/ani"
                        },
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/assign_clade_bacteria/asn_cache"
                        },
                        {
                            "source": "#main/assembly_id",
                            "id": "#main/assign_clade_bacteria/assembly_id"
                        },
                        {
                            "source": "#main/reference_set",
                            "id": "#main/assign_clade_bacteria/reference_set"
                        },
                        {
                            "source": "#main/align_sort/sorted_aligns",
                            "id": "#main/assign_clade_bacteria/sorted_aligns"
                        }
                    ],
                    "out": [
                        "#main/assign_clade_bacteria/clade_assignment"
                    ],
                    "id": "#main/assign_clade_bacteria"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
